@@ -16,12 +16,12 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
  *************************************************************************************/
 #include "waylandoutput.h"
+#include "../utils.h"
 #include "waylandbackend.h"
 #include "waylandconfig.h"
-#include "../utils.h"
 
-#include <mode.h>
 #include <edid.h>
+#include <mode.h>
 
 #include <KWayland/Client/outputconfiguration.h>
 #include <KWayland/Client/outputdevice.h>
@@ -29,22 +29,19 @@
 using namespace KScreen;
 namespace Wl = KWayland::Client;
 
-const QMap<Wl::OutputDevice::Transform, Output::Rotation>
-s_rotationMap = {
-    {Wl::OutputDevice::Transform::Normal, Output::None},
-    {Wl::OutputDevice::Transform::Rotated90, Output::Right},
-    {Wl::OutputDevice::Transform::Rotated180, Output::Inverted},
-    {Wl::OutputDevice::Transform::Rotated270, Output::Left},
-    {Wl::OutputDevice::Transform::Flipped, Output::None},
-    {Wl::OutputDevice::Transform::Flipped90, Output::Right},
-    {Wl::OutputDevice::Transform::Flipped180, Output::Inverted},
-    {Wl::OutputDevice::Transform::Flipped270, Output::Left}
-};
+const QMap<Wl::OutputDevice::Transform, Output::Rotation> s_rotationMap = //
+    {{Wl::OutputDevice::Transform::Normal, Output::None},
+     {Wl::OutputDevice::Transform::Rotated90, Output::Right},
+     {Wl::OutputDevice::Transform::Rotated180, Output::Inverted},
+     {Wl::OutputDevice::Transform::Rotated270, Output::Left},
+     {Wl::OutputDevice::Transform::Flipped, Output::None},
+     {Wl::OutputDevice::Transform::Flipped90, Output::Right},
+     {Wl::OutputDevice::Transform::Flipped180, Output::Inverted},
+     {Wl::OutputDevice::Transform::Flipped270, Output::Left}};
 
 Output::Rotation toKScreenRotation(const Wl::OutputDevice::Transform transform)
 {
-    auto it = s_rotationMap.constFind(transform);
-    return it.value();
+    return s_rotationMap.value(transform);
 }
 
 Wl::OutputDevice::Transform toKWaylandTransform(const Output::Rotation rotation)
@@ -70,7 +67,7 @@ bool WaylandOutput::enabled() const
     return m_device != nullptr;
 }
 
-Wl::OutputDevice* WaylandOutput::outputDevice() const
+Wl::OutputDevice *WaylandOutput::outputDevice() const
 {
     return m_device;
 }
@@ -82,8 +79,8 @@ void WaylandOutput::createOutputDevice(Wl::Registry *registry, quint32 name, qui
 
     connect(m_device, &Wl::OutputDevice::removed, this, &WaylandOutput::deviceRemoved);
     connect(m_device, &Wl::OutputDevice::done, this, [this]() {
-                Q_EMIT complete();
-                connect(m_device, &Wl::OutputDevice::changed, this, &WaylandOutput::changed);
+        Q_EMIT complete();
+        connect(m_device, &Wl::OutputDevice::changed, this, &WaylandOutput::changed);
     });
 }
 
@@ -106,20 +103,23 @@ void WaylandOutput::updateKScreenOutput(OutputPtr &output)
     output->setSizeMm(m_device->physicalSize());
     output->setPos(m_device->globalPosition());
     output->setRotation(s_rotationMap[m_device->transform()]);
+    if (!output->edid()) {
+        output->setEdid(m_device->edid());
+    }
 
     ModeList modeList;
     QStringList preferredModeIds;
     m_modeIdMap.clear();
     QString currentModeId = QStringLiteral("-1");
 
+    QSize currentSize;
     for (const Wl::OutputDevice::Mode &wlMode : m_device->modes()) {
         ModePtr mode(new Mode());
         const QString name = modeName(wlMode);
 
         QString modeId = QString::number(wlMode.id);
         if (modeId.isEmpty()) {
-            qCDebug(KSCREEN_WAYLAND) << "Could not create mode id from"
-                                     << wlMode.id << ", using" << name << "instead.";
+            qCDebug(KSCREEN_WAYLAND) << "Could not create mode id from" << wlMode.id << ", using" << name << "instead.";
             modeId = name;
         }
 
@@ -134,6 +134,7 @@ void WaylandOutput::updateKScreenOutput(OutputPtr &output)
         mode->setName(name);
 
         if (wlMode.flags.testFlag(Wl::OutputDevice::Mode::Flag::Current)) {
+            currentSize = wlMode.size;
             currentModeId = modeId;
         }
         if (wlMode.flags.testFlag(Wl::OutputDevice::Mode::Flag::Preferred)) {
@@ -150,6 +151,7 @@ void WaylandOutput::updateKScreenOutput(OutputPtr &output)
         qCWarning(KSCREEN_WAYLAND) << "Could not find the current mode id" << modeList;
     }
 
+    output->setSize(output->isHorizontal() ? currentSize : currentSize.transposed());
     output->setCurrentModeId(currentModeId);
     output->setPreferredModes(preferredModeIds);
     output->setModes(modeList);
@@ -157,17 +159,14 @@ void WaylandOutput::updateKScreenOutput(OutputPtr &output)
     output->setType(Utils::guessOutputType(m_device->model(), m_device->model()));
 }
 
-bool WaylandOutput::setWlConfig(Wl::OutputConfiguration *wlConfig,
-                                const KScreen::OutputPtr &output)
+bool WaylandOutput::setWlConfig(Wl::OutputConfiguration *wlConfig, const KScreen::OutputPtr &output)
 {
     bool changed = false;
 
     // enabled?
-    if ((m_device->enabled() == Wl::OutputDevice::Enablement::Enabled)
-            != output->isEnabled()) {
+    if ((m_device->enabled() == Wl::OutputDevice::Enablement::Enabled) != output->isEnabled()) {
         changed = true;
-        const auto enablement = output->isEnabled() ? Wl::OutputDevice::Enablement::Enabled :
-                                                      Wl::OutputDevice::Enablement::Disabled;
+        const auto enablement = output->isEnabled() ? Wl::OutputDevice::Enablement::Enabled : Wl::OutputDevice::Enablement::Disabled;
         wlConfig->setEnabled(m_device, enablement);
     }
 
@@ -197,17 +196,15 @@ bool WaylandOutput::setWlConfig(Wl::OutputConfiguration *wlConfig,
             wlConfig->setMode(m_device, newModeId);
         }
     } else {
-        qCWarning(KSCREEN_WAYLAND) << "Invalid kscreen mode id:" << output->currentModeId()
-                                   << "\n\n" << m_modeIdMap;
+        qCWarning(KSCREEN_WAYLAND) << "Invalid kscreen mode id:" << output->currentModeId() << "\n\n" << m_modeIdMap;
     }
     return changed;
 }
 
 QString WaylandOutput::modeName(const Wl::OutputDevice::Mode &m) const
 {
-    return QString::number(m.size.width()) + QLatin1Char('x') +
-           QString::number(m.size.height()) + QLatin1Char('@') +
-           QString::number(qRound(m.refreshRate/1000.0));
+    return QString::number(m.size.width()) + QLatin1Char('x') + QString::number(m.size.height()) + QLatin1Char('@')
+        + QString::number(qRound(m.refreshRate / 1000.0));
 }
 
 QString WaylandOutput::name() const
@@ -218,8 +215,7 @@ QString WaylandOutput::name() const
 
 QDebug operator<<(QDebug dbg, const WaylandOutput *output)
 {
-    dbg << "WaylandOutput(Id:" << output->id() <<", Name:" << \
-        QString(output->outputDevice()->manufacturer() + QLatin1Char(' ') + \
-        output->outputDevice()->model())  << ")";
+    dbg << "WaylandOutput(Id:" << output->id()
+        << ", Name:" << QString(output->outputDevice()->manufacturer() + QLatin1Char(' ') + output->outputDevice()->model()) << ")";
     return dbg;
 }
