@@ -39,10 +39,7 @@ public:
 
     KScreen::ScreenPtr toKScreenScreen(KScreen::ConfigPtr &parent) const;
     void updateKScreenScreen(KScreen::ScreenPtr &screen) const;
-    void setOutputs(const QList<WaylandOutput*> &outputs);
-
-    void setSize(const QSize &size);
-    void setOutputCount(int count);
+    void setOutputs(const QList<WaylandOutput *> &outputs);
 
 private:
     QSize m_size;
