@@ -19,25 +19,25 @@
 #ifndef KSCREEN_DPMSCLIENT_H
 #define KSCREEN_DPMSCLIENT_H
 
-#include <QCommandLineParser>
-#include <QObject>
 #include "../config.h"
+#include <QObject>
+#include <QRect>
 
-#include <KWayland/Client/registry.h>
 #include <KWayland/Client/dpms.h>
+#include <KWayland/Client/registry.h>
 
 class QThread;
 
 namespace KWayland
 {
-    namespace Client {
-        class ConnectionThread;
-    }
+namespace Client
+{
+class ConnectionThread;
+}
 }
 
 namespace KScreen
 {
-
 class DpmsClient : public QObject
 {
     Q_OBJECT
@@ -46,6 +46,11 @@ public:
     explicit DpmsClient(QObject *parent = nullptr);
     ~DpmsClient() override;
 
+    void setExcludedOutputNames(const QStringList &excluded)
+    {
+        m_excludedOutputNames = excluded;
+    }
+
     void connect();
     void off();
     void on();
@@ -63,12 +68,13 @@ private:
     QThread *m_thread;
     KWayland::Client::ConnectionThread *m_connection = nullptr;
     KWayland::Client::DpmsManager *m_dpmsManager = nullptr;
-    KWayland::Client::Registry m_registry;
+    KWayland::Client::Registry *m_registry = nullptr;
     bool m_setOff = true;
     bool m_setOn = false;
 
     bool m_supportedOututCount = 0;
     int m_modeChanges = 0;
+    QStringList m_excludedOutputNames;
 };
 
 } // namespace
